@@ -4,7 +4,7 @@
 ;#
 ;# Copyright (C) Jose E. Marchesi
 ;#
-;# Time-stamp: "2003-07-07 08:08:55 jemarch"
+;# Time-stamp: "2003-07-08 11:42:37 jemarch"
 
 ;# This program is free software; you can redistribute it and/or
 ;# modify it under the terms of the GNU General Public License as
@@ -38,6 +38,8 @@ proc gui_init {widget} {
 
     set gmainframe ${widget}
     
+    ;# Title
+    wm title . "Gerwin $gerwin_version"
 
     ;# Make the mainframe
     MainFrame ${gmainframe} -separator both \
